# adex-data-scraper

The `adex-data-scraper` is a pip installable runnable package that can be used to import data from our archives (primarily astron-vo) into the ADEX backend

See also: https://git.astron.nl/astron-sdc/adex-backend-django

## Architecture

`adex-data-scraper` lives between the astron-vo datasources and the ADEX-cache database.
It is (currently) a pip installable program that can be run manually.

![](/docs/adex-architecture.png)

See [SDC Architecture Focus Project](https://support.astron.nl/confluence/display/SDCP/SDC+Architecture%3A+Focus+Project) 
for more detailed architecture information.


## Building (automatic)
The CI/CD pipeline builds and uploads the software to the [ASTRON gitlab package registry](https://git.astron.nl/astron-sdc/adex-data-scraper/-/packages).

## Deploying (manually)
For example on `sdc@dop814.astron.nl` (this is our sdc-dev test machine) 

```
# only once
> cd ~
> mkdir adex-data-scraper
> cd adex-data-scraper
> virtualenv env3.9 -p python3.9 (on ubuntu)
> python3 -m venv env3.9 (on centos)

# for every deployment
> cd ~/adex-data-scraper
> source env3.9/bin/activate
> pip install --upgrade pip
> pip install adex-data-scraper --extra-index-url https://git@git.astron.nl/api/v4/projects/349/packages/pypi/simple --upgrade

```

## Running

To test if it works (look at the version)
```
> adex_data_scraper -h
--- adex-data-scraper (version 14 feb 2023) ---
```

Getting help
```
  > adex_data_scraper -h
usage: main.py [-h] [--datasource DATASOURCE] [--data_host DATA_HOST]
               [--connector CONNECTOR] [--limit LIMIT]
               [--batch_size BATCH_SIZE]
               [--adex_backend_host [ADEX_BACKEND_HOST]]
               [--adex_resource ADEX_RESOURCE] [--collection COLLECTION]
               [--clear_resource] [--clear_collection] [--simulate_post]
               [--adex_token ADEX_TOKEN] [-v] [--argfile [ARGFILE]]

options:
  -h, --help            show this help message and exit
  --datasource DATASOURCE
                        where should the data be imported from? Options: vo,
                        postgres
  --data_host DATA_HOST
                        service/table, either VO or postgres. Examples:
                        https://vo.astron.nl/tap/apertif_dr1.continuum_images,
                        postgres:postgres@localhost:5432/alta
  --connector CONNECTOR
                        Connector class containing the translation scheme from
                        vo to adex
  --limit LIMIT         max records to fetch from VO, for dev/test purposes
  --batch_size BATCH_SIZE
                        number of records to post as a batch to ADEX
  --adex_backend_host [ADEX_BACKEND_HOST]
                        location of the adex-backend-django application
  --adex_resource ADEX_RESOURCE
                        resource/table to update, options are:
                        primary_dp/create, ancillary_dp/create,
                        activity/create
  --collection COLLECTION
                        can be used as filter in ADEX backend and ADEX
                        frontend
  --clear_resource      Delete all the data from the adex_resource
  --clear_collection    Delete all the data for this collection from the
                        adex_resource, works in concert with the '--
                        collection' parameter.
  --simulate_post       If true, then no data is posted to ADEX
  --adex_token          ADEX_TOKEN
                        Token to login
  -v, --verbose         More information about atdb_services at run time.
  --argfile [ARGFILE]   Ascii file with arguments (overrides all other
                        arguments

Process finished with exit code 0

```

## Development

`adex-data-scraper` can be used to fill the ADEX cache database with data from ASTRON VO.
The [examples](https://git.astron.nl/astron-sdc/adex-data-scraper/-/tree/main/examples) directory in this repo 
shows some 'argument files' for different datasets and communication paths.

See [this diagram](https://drive.google.com/file/d/19Gim-tI75F242gXhzhcvRl1ZUpSOoMOW/view) for the current development

![](/docs/adex-data-scraper-implementation.png)

### Connectors

The implementation of the [connectors](https://git.astron.nl/astron-sdc/adex-data-scraper/-/blob/main/scraper/vo/connectors.py) need to follow the [ADEX datamodel](https://drive.google.com/file/d/1WBT1XxD23LYmEYs4TRdrE8dbcJDv0O5s/view?usp=sharing),
and the datamodel in astron-vo. Both datamodels are still under development.


## Visualisation in adex-labs
This is a visualisation of the apertif-dr1 example in adex-labs engineering frontend.

![](/docs/adex-labs.jpg)


### Examples
The `examples` folder contains a series of argument files that show to use the adex-data-scraper
The differences in the examples are mainly the different servers that can be used.

These 2 are highlighted as an example of a primary and ancillary dataset that belong together: 
```
adex_data_scraper --argfile examples\vo\apertif_dr1_continuum_images_localhost.args
adex_data_scraper --argfile examples\postgres\ancillary_apertif_inspectionplots_localhost.args
